# cxpandascsvloader
A simple example package for loading and processing CSV data into Pandas DataFrames.

## Installation
You can install the `cxpandascsvloader` package using pip:

```sh
pip install cxpandascsvloader
```

## Usage
```sh
import cxpandascsvloader.dataframeloader as dfl
dfl.printinfo()
## output: dataframeloader module loaded


